@@ -6,10 +6,12 @@ from office.api import video
 from office.api import tools
 from office.api import ppt
 from office.api import excel
+# 以下是beta版本
+from office.api.testApi import ruiming
 
 print('=' * 30)
 print('【python-office库】，功能持续更新中')
-print( '全部功能 - 说明书 -：https://www.python-office.com/')
+print('全部功能 - 说明书 -：https://www.python-office.com/')
 print('使用有问题 or 提交你的功能需求 or 参与项目开发')
 print('请+【开发者微信】：http://t.cn/A6SSrID0')
 print('本开源项目的源码：https://github.com/CoderWanFeng/python-office')
